@@ -1,17 +1,18 @@
 package Padre::Plugin::Catalyst::Outline;
+BEGIN {
+  $Padre::Plugin::Catalyst::Outline::VERSION = '0.11';
+}
+
+# ABSTRACT: A Catalyst plugin outline
 
 use strict;
 use warnings;
 
-use Padre::Wx   ();
-use Padre::Util ('_T');
+use Padre::Wx ();
 use Wx;
 
 use base 'Wx::TreeCtrl';
 
-our $VERSION = '0.09';
-
-
 sub new {
 	my $class  = shift;
 	my $plugin = shift;
@@ -101,9 +102,44 @@ sub populate {
 }
 
 sub gettext_label {
-	_T('Catalyst');
+	Wx::gettext('Catalyst');
 }
 
 
 1;
 
+
+__END__
+=pod
+
+=head1 NAME
+
+Padre::Plugin::Catalyst::Outline - A Catalyst plugin outline
+
+=head1 VERSION
+
+version 0.11
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Breno G. de Oliveira <garu@cpan.org>
+
+=item *
+
+Ahmad M. Zawawi <ahmad.zawawi@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Breno G. de Oliveira.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
